@@ -5,7 +5,7 @@ data <- list(
     c("A", "B", "C", "G"),
     c("C", "D"),
     c("E", "F"),
-    c("A", "B", "C", "D"),
+    c("A", "B", "C", "D")
     )
 
 
